#!/bin/bash

## This script is exporting data from OpenSearch cluster,
## it is collecting data for auditlog and exporting them to S3 bucket
# The script takes two arguments - the Elasticsearch endpoint and the environment name (free form)

DATE=$(date +%Y-%m-%d)
TIME=$(date +%Y-%m-%d-%H-%M-%S)
SKIP_ENVS=("kcdev01" "int1usw2" "scl2use2" "scl4use2") #"int2use2" "kctest03"

# Map of cluster names to Legacy environment names
case $ENV in

  kcdev01)
    LEGACY="dev01"
    BUCKET="defense-bi-analytics-dev01"
    ;;

  int1usw2)
    LEGACY="int1usw2"
    BUCKET="defense-bi-analytics-dev01"
    ;;

  kctest03)
    LEGACY="kctest03"
    BUCKET="defense-bi-analytics-dev01"
    ;;

  int2use2)
    LEGACY="int2use2"
    BUCKET="defense-bi-analytics-cb-dev"
    ;;

  prd1apne1)
    LEGACY="prodnrt"
    BUCKET="defense-bi-analytics-hub01"
    ;;

  prd1apse2)
    LEGACY="prodsyd"
    BUCKET="defense-bi-analytics-hub01"
    ;;

  prd1ec1)
    LEGACY="prod06"
    BUCKET="defense-bi-analytics-hub01"
    ;;

  prd1ew2)
    LEGACY="prd1ew2"
    BUCKET="defense-bi-analytics-hub01"
    ;;

  prd5use1)
    LEGACY=("prod01" "prod02" "prod05" "eap01")
    BUCKET="defense-bi-analytics-hub01"
    ;;

  *)
    LEGACY="not_set"
    ;;

esac

for i in ${!LEGACY[@]};
  do
    if [[ ${SKIP_ENVS[@]} =~ $ENV ]]; then
      echo "Skip the exports for dev/test environments ..."
    else
      AUDIT_LOG=/home/docker/$TIME-audit_log_stats-${LEGACY[i]}.log

      # run export script for audit-log-stats
      node app-auditlog.js $1 443 ${LEGACY[i]} > $AUDIT_LOG

      if [ -f $AUDIT_LOG ]; then
        aws s3 cp $AUDIT_LOG s3://$BUCKET/deployment_stats/audit_log_stats/$DATE/
      fi
    fi
done
