#!/bin/bash
# This script is helper for running various other scripts
# for exporting ElasticSearch data to S3 bucket
#
# The script takes three arguments - the Elasticsearch endpoint, the environment name and the ES endpoint maps (free form)

DATE=$(date +%Y-%m-%d)
TIME=$(date +%Y-%m-%d-%H-%M-%S)
SKIP_ENVS=("scl2use2" "scl4use2") # "int1usw2" "kcdev01"

# Write the json in file
echo "Print ES_HOSTS variable"
echo $ES_HOSTS >> hosts

case $ENV in

  kcdev01)
    BUCKET="defense-bi-analytics-dev01"
    PORT=9200
    ENDPOINTS=("$ES_HOST")
    ENV="dev01"
    ;;

  int1usw2)
    BUCKET="defense-bi-analytics-dev01"
    PORT=443
    ENV="int1usw2"
    ES_HOST_EXTRACTED=$(jq -r '.int1usw2[0]' hosts | awk '{split($0, url, /[\/\@:]*/); print url[2] }')
    ENDPOINTS=("$ES_HOST_EXTRACTED")
    ;;

  kctest03)
    BUCKET="defense-bi-analytics-dev01"
    PORT=9200
    ENDPOINTS=("$ES_HOST")
    ;;

  int2use2)
    BUCKET="defense-bi-analytics-cb-dev"
    PORT=443
    ENDPOINTS=("$ES_HOST")
    ;;

  prd1ew2)
    BUCKET="defense-bi-analytics-hub01"
    PORT=443
    ENDPOINTS=("$ES_HOST")
    ;;

  prd5use1)
    BUCKET="defense-bi-analytics-hub01"
    PORT=9200
    ES_HOST_EAP01=$(jq -r '.eap01[0]' hosts | awk '{split($0, url, /[\/\@:]*/); print url[2] }')
    ES_HOST_PROD01=$(jq -r '.prod01[0]' hosts | awk '{split($0, url, /[\/\@:]*/); print url[2] }')
    ES_HOST_PROD02=$(jq -r '.prod02[0]' hosts | awk '{split($0, url, /[\/\@:]*/); print url[2] }')
    ES_HOST_PROD05=$(jq -r '.prod05[0]' hosts | awk '{split($0, url, /[\/\@:]*/); print url[2] }')
    ENDPOINTS=("$ES_HOST_EAP01" "$ES_HOST_PROD01" "$ES_HOST_PROD02" "$ES_HOST_PROD05")
    ;;

  prd1apne1)
    PORT=9200
    ENV="prodnrt"
    BUCKET="defense-bi-analytics-hub01"
    ;;

  prd1apse2)
    PORT=9200
    ENV="prodsyd"
    BUCKET="defense-bi-analytics-hub01"
    ;;

  prd1ec1)
    PORT=9200
    ENV="prod06"
    BUCKET="defense-bi-analytics-hub01"
    ;;

  *)
    BUCKET="defense-bi-analytics-hub01"
    PORT=9200
    ;;

esac

if [[ ${SKIP_ENVS[@]} =~ $ENV ]]; then
  echo "Skip the exports for dev/test environments ..."
else
  for i in ${!ENDPOINTS[@]};
  do
    ENDPOINT=${ENDPOINTS[i]}
    ENV_NAME=$(echo ${ENDPOINT} | cut -d '-' -f 3 | cut -d '.' -f 1)

    # ENV is coming from K8s secret and stores the new environments names: prd5use1, prd1ew2 and etc.
    # For the legacy environments, except the us-east-1 ones, it's overwritten with the environment legacy name
    # The us-east-1 environments legacy names is extracted from the ENDPOINT: prod05, eap01 and etc;
    if [[ $ENV != "prd5use1" ]]; then
      ENV_NAME=${ENV}
    fi

    AVIRA_LOG=/home/docker/$TIME-avstats-$ENV_NAME.log
    SENSOR_LOG=/home/docker/$TIME-org_stats-$ENV_NAME.log

    # run export script for sensor-stats
    echo "Execute orgstats script towards the $ENDPOINT:$PORT ..."
    node app-orgstats.js $ENDPOINT $PORT > $SENSOR_LOG

    # run export script for avira-stats
    echo "Execute avstats script towards the $ENDPOINT:$PORT ..."
    node app-avstats.js $ENDPOINT $PORT > $AVIRA_LOG

    if [ -f $SENSOR_LOG ]; then
      echo "Copy ${SENSOR_LOG} to s3 ..."
      aws s3 cp $SENSOR_LOG s3://$BUCKET/deployment_stats/sensor_stats_mcs2_test/$DATE/
    fi

    if [ -f $AVIRA_LOG ]; then
      echo "Copy ${AVIRA_LOG} to s3 ..."
      aws s3 cp $AVIRA_LOG s3://$BUCKET/deployment_stats/avstats_mcs2_test/$DATE/
    fi
  done
fi



